@@ -5,7 +5,7 @@ use Carp qw(croak cluck);
 use Statistics::Data 0.09;
 use base qw(Statistics::Data);
 use Scalar::Util qw(looks_like_number);
-$Statistics::Sequences::VERSION = '0.13';
+$Statistics::Sequences::VERSION = '0.14';
 
 =pod
 
@@ -15,11 +15,11 @@ Statistics::Sequences - Manage sequences (ordered list of literals) for testing
 
 =head1 VERSION
 
-This is documentation for Version 0.13 of Statistics::Sequences.
+This is documentation for Version 0.14 of Statistics::Sequences.
 
 =head1 SYNOPSIS
 
- use Statistics::Sequences 0.13;
+ use Statistics::Sequences 0.14;
  $seq = Statistics::Sequences->new();
  my @data = (1, 'a', 'a', 1); # ordered list of literal scalars (numbers, strings), as permitted by specific test
  $seq->load(\@data); # or @data or dataname => \@data
@@ -67,7 +67,7 @@ Return the observed value of the statistic for the L<load|Statistics::Sequences/
 
 =cut
 
-sub observed { return _feedme( 'observed', @_ ); }
+sub observed { return _feed( 'observed', @_ ); }
 *observation = \&observed;
 
 =head2 expected, expectation
@@ -79,7 +79,7 @@ Return the expected value of the statistic for the L<load|Statistics::Sequences/
 
 =cut
 
-sub expected { return _feedme( 'expected', @_ ); }
+sub expected { return _feed( 'expected', @_ ); }
 *expectation = \&expected;
 
 =head2 variance
@@ -91,7 +91,7 @@ Returns the expected range of deviation in the statistic's observed value for th
 
 =cut
 
-sub variance { return _feedme( 'variance', @_ ); }
+sub variance { return _feed( 'variance', @_ ); }
 
 =head2 obsdev, observed_deviation
 
@@ -130,7 +130,7 @@ Return the deviation ratio: observed deviation to standard deviation. Use argume
 
 =cut
 
-sub zscore { return _feedme( 'zscore', @_ ); }
+sub zscore { return _feed( 'zscore', @_ ); }
 *z_value = \&zscore;
 
 =head2 p_value, test
@@ -184,7 +184,7 @@ B<Runs>, B<Turns> : There are presently no specific requirements nor options for
 
 =cut
 
-sub p_value { return _feedme( 'p_value', @_ ); }
+sub p_value { return _feed( 'p_value', @_ ); }
 *test = \&p_value;
 
 =head2 stats_hash
@@ -365,7 +365,7 @@ Prints to STDOUT a space-separated line of the tested data - as dichotomized and
 
 # PRIVATMETHODEN
 
-sub _feedme {
+sub _feed {
     my $method   = shift;
     my $self     = shift;
     my $args     = ref $_[0] ? $_[0] : {@_};
@@ -415,19 +415,19 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Statistics-Sequences-0.13>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Statistics-Sequences-0.14>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/Statistics-Sequences-0.13>
+L<http://annocpan.org/dist/Statistics-Sequences-0.14>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/Statistics-Sequences-0.13>
+L<http://cpanratings.perl.org/d/Statistics-Sequences-0.14>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/Statistics-Sequences-0.13/>
+L<http://search.cpan.org/dist/Statistics-Sequences-0.14/>
 
 =back
 
@@ -435,7 +435,7 @@ L<http://search.cpan.org/dist/Statistics-Sequences-0.13/>
 
 =over 4
 
-=item Copyright (c) 2006-2015 Roderick Garton
+=item Copyright (c) 2006-2016 Roderick Garton
 
 This program is free software. It may be used, redistributed and/or modified under the same terms as Perl-5.6.1 (or later) (see L<http://www.perl.com/perl/misc/Artistic.html>).
 
